@@ -1,9 +1,11 @@
 package EBook::Ishmael::EBook::PDF;
 use 5.016;
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 use strict;
 use warnings;
 
+use File::Temp qw(tempdir);
+
 use File::Which;
 use XML::LibXML;
 
@@ -15,6 +17,7 @@ use EBook::Ishmael::EBook::Metadata;
 
 my $PDFTOHTML = which 'pdftohtml';
 my $PDFINFO   = which 'pdfinfo';
+my $PDFTOPNG  = which 'pdftopng';
 
 my $MAGIC = '%PDF';
 
@@ -134,6 +137,41 @@ sub html {
 
 }
 
+sub raw {
+
+	my $self = shift;
+	my $out  = shift;
+
+	unless (defined $PDFTOHTML) {
+		die "Cannot read PDF $self->{Source}: pdftohtml not installed\n";
+	}
+
+	my $raw = '';
+
+	open my $fh, '>', $out // \$raw
+		or die sprintf "Failed to open %s for writing: $!\n", $out // 'in-memory scalar';
+	binmode $fh, ':utf8';
+
+	my $rawml = qx/$PDFTOHTML -i -s -stdout "$self->{Source}"/;
+
+	unless ($? >> 8 == 0) {
+		die "Failed to run '$PDFTOHTML' on $self->{Source}\n";
+	}
+
+	my $dom = XML::LibXML->load_html(
+		string => $rawml
+	);
+
+	my ($body) = $dom->findnodes('/html/body');
+
+	print { $fh } $body->textContent;
+
+	close $fh;
+
+	return $out // $raw;
+
+}
+
 sub metadata {
 
 	my $self = shift;
@@ -142,4 +180,53 @@ sub metadata {
 
 }
 
+sub has_cover { 1 }
+
+# Just use pdftopng to convert the first page of the PDF to a png then use that
+# as the cover.
+sub cover {
+
+	my $self = shift;
+	my $out  = shift;
+
+	unless (defined $PDFTOPNG) {
+		die "Cannot dump PDF $self->{Source} cover: pdftopng not installed\n";
+	}
+
+	my $tmpdir = tempdir(CLEANUP => 1);
+	my $tmproot = File::Spec->catfile($tmpdir, 'tmp');
+
+	qx/$PDFTOPNG -f 1 -l 1 "$self->{Source}" "$tmproot"/;
+
+	unless ($? >> 8 == 0) {
+		die "Failed to run '$PDFTOPNG' on $self->{Source}\n";
+	}
+
+	my ($png) = glob "$tmpdir/*";
+
+	unless (defined $png) {
+		die "'$PDFTOPNG' could not produce a cover image from $self->{Source}\n";
+	}
+
+	my $bin;
+
+	open my $wh, '>', $out // \$bin
+		or die sprintf "Failed to open %s for writing: $!\n", $out // 'in-memory scalar';
+	binmode $wh;
+
+	open my $rh, '<', $png
+		or die "Failed to open $png for reading: $!\n";
+	binmode $rh;
+
+	while (read $rh, my ($buf), 1024) {
+		print { $wh } $buf;
+	}
+
+	close $wh;
+	close $rh;
+
+	return $out // $bin;
+
+}
+
 1;
